/**
 * Grava a resposta escolhida pelo usuario.
 *
 * Observacoes:
 * - As respostas sao gravadas na tabela RESPAVALIACAO.
 *
 * @author Ederson Melquiades da Cunha <ederson@teknisa.com>
 *
 * @param P_NRORG IN Organizacao logada
 * @param P_CDOPERADOR IN Operador logado
 * @param P_NRRESPAVALIACAO IN OUT Numero sequencial da resposta (opcional, passar 0 para novo registro)
 * @param P_NREXECAVALIACAO IN Nmero da questao que foi respondida (EXECAVALIACAO)
 * @param P_NRRESPOSTA IN Numero do parceiro de negocios que executara a avaliao (opcional)
 *
 */

CREATE OR REPLACE
PROCEDURE AVL_GRAVA_RESPAVALIACAO (
   P_NRORG IN ORGANIZACAO.NRORG%TYPE,
   P_CDOPERADOR OPERADOR.CDOPERADOR%TYPE,
   P_NRRESPAVALIACAO IN OUT RESPAVALIACAO.NRRESPAVALIACAO%TYPE,
   P_NREXECAVALIACAO IN RESPAVALIACAO.NREXECAVALIACAO%TYPE,
   P_NRRESPOSTA IN RESPAVALIACAO.NRRESPOSTA%TYPE DEFAULT NULL,
   P_TXRESPAVALIACAO IN RESPAVALIACAO.TXRESPAVALIACAO%TYPE DEFAULT NULL,
   P_DTRESPAVALIACAO IN RESPAVALIACAO.DTRESPAVALIACAO%TYPE DEFAULT NULL,
   P_VRRESPAVALIACAO IN RESPAVALIACAO.VRRESPAVALIACAO%TYPE DEFAULT NULL,
   P_TXOBSCORRECAVAL IN RESPAVALIACAO.TXOBSCORRECAVAL%TYPE DEFAULT NULL,
   P_VRNOTARESPAVAL IN RESPAVALIACAO.VRNOTARESPAVAL%TYPE DEFAULT NULL
) IS
   V_NRRESPAVALIACAO NOVOCODIGO.NRSEQUENCIAL%TYPE;
BEGIN
   IF P_NRRESPAVALIACAO = -1 THEN
--   IF P_NRRESPAVALIACAO IS NULL THEN
      NOVO_CODIGO('RESPAVALIACAO', V_NRRESPAVALIACAO, 1, P_NRORG);
      P_NRRESPAVALIACAO := V_NRRESPAVALIACAO;
      INSERT INTO RESPAVALIACAO
            (NRORG, NRRESPAVALIACAO, NREXECAVALIACAO, 
             NRRESPOSTA, TXRESPAVALIACAO, DTRESPAVALIACAO, 
             VRRESPAVALIACAO, TXOBSCORRECAVAL, VRNOTARESPAVAL,
             IDATIVO, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU)
      SELECT P_NRORG, P_NRRESPAVALIACAO, P_NREXECAVALIACAO, 
             P_NRRESPOSTA, P_TXRESPAVALIACAO, P_DTRESPAVALIACAO, 
             P_VRRESPAVALIACAO, P_TXOBSCORRECAVAL, P_VRNOTARESPAVAL,
             'S', SYSDATE, SYSDATE, P_NRORG, P_CDOPERADOR, P_NRORG, P_CDOPERADOR
        FROM DUAL
       WHERE NOT EXISTS
             (SELECT *
                FROM RESPAVALIACAO
               WHERE NRORG = P_NRORG
                 AND NREXECAVALIACAO = P_NREXECAVALIACAO
                 AND NRRESPOSTA = P_NRRESPOSTA);
   ELSE
      UPDATE RESPAVALIACAO
         SET NRRESPOSTA = CASE WHEN P_NRRESPOSTA IS NULL THEN NRRESPOSTA ELSE P_NRRESPOSTA END,
             TXRESPAVALIACAO = CASE WHEN P_TXRESPAVALIACAO IS NULL THEN TXRESPAVALIACAO ELSE P_TXRESPAVALIACAO END,
             DTRESPAVALIACAO = CASE WHEN P_DTRESPAVALIACAO IS NULL THEN DTRESPAVALIACAO ELSE P_DTRESPAVALIACAO END,
             VRRESPAVALIACAO = CASE WHEN P_VRRESPAVALIACAO IS NULL THEN VRRESPAVALIACAO ELSE P_VRRESPAVALIACAO END,
             TXOBSCORRECAVAL = CASE WHEN P_TXOBSCORRECAVAL IS NULL THEN TXOBSCORRECAVAL ELSE P_TXOBSCORRECAVAL END,
             VRNOTARESPAVAL = CASE WHEN P_VRNOTARESPAVAL IS NULL THEN VRNOTARESPAVAL ELSE P_VRNOTARESPAVAL END,   
             DTULTATU = SYSDATE,
             NRORGULTATU = P_NRORG,
             CDOPERULTATU = P_CDOPERADOR
       WHERE NRORG = P_NRORG
         AND NRRESPAVALIACAO = P_NRRESPAVALIACAO;
   END IF;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('AVL_GRAVA_RESPAVALIACAO','5.55.010'); END;
/

